fmu-sumo
########

Sumo is a solution for indexing, storing and supplying results produced by FMU workflows
and associated processes (post-processing). See the `Sumo front-end for FMU <https://fmu-sumo.app.radix.equinor.com>`_
for additional information and documentation on Sumo.

``fmu-sumo`` is a Python library for interaction with FMU results stored in Sumo. It contains
the Explorer modules:

* **Explorer** (This module) for *reading* data from Sumo in the FMU context.


.. toctree::
    :maxdepth: 2
    :hidden:

    self
    explorer
